You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@iotdb.apache.org by ha...@apache.org on 2021/03/04 07:27:19 UTC

[iotdb] branch MemSize created (now dc67d24)

This is an automated email from the ASF dual-hosted git repository.

haonan pushed a change to branch MemSize
in repository https://gitbox.apache.org/repos/asf/iotdb.git.


      at dc67d24  change the default max JVM heap size from 8G to 64G

This branch includes the following new commits:

     new dc67d24  change the default max JVM heap size from 8G to 64G

The 1 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.



[iotdb] 01/01: change the default max JVM heap size from 8G to 64G

Posted by ha...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

haonan pushed a commit to branch MemSize
in repository https://gitbox.apache.org/repos/asf/iotdb.git

commit dc67d245740fd13b46fca4d95a33419b979405a2
Author: HTHou <hh...@outlook.com>
AuthorDate: Thu Mar 4 15:26:30 2021 +0800

    change the default max JVM heap size from 8G to 64G
---
 server/src/assembly/resources/conf/iotdb-env.bat | 2 +-
 server/src/assembly/resources/conf/iotdb-env.sh  | 8 ++++----
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/server/src/assembly/resources/conf/iotdb-env.bat b/server/src/assembly/resources/conf/iotdb-env.bat
index c915a16..9c73f03 100644
--- a/server/src/assembly/resources/conf/iotdb-env.bat
+++ b/server/src/assembly/resources/conf/iotdb-env.bat
@@ -68,7 +68,7 @@ set /a half_=%system_memory_in_mb%/2
 set /a quarter_=%half_%/2
 
 if ["%half_%"] GTR ["1024"] set half_=1024
-if ["%quarter_%"] GTR ["8192"] set quarter_=8192
+if ["%quarter_%"] GTR ["65536"] set quarter_=65536
 
 if ["%half_%"] GTR ["quarter_"] (
 	set max_heap_size_in_mb=%half_%
diff --git a/server/src/assembly/resources/conf/iotdb-env.sh b/server/src/assembly/resources/conf/iotdb-env.sh
index 9dc2bc2..c9dcdec 100755
--- a/server/src/assembly/resources/conf/iotdb-env.sh
+++ b/server/src/assembly/resources/conf/iotdb-env.sh
@@ -66,9 +66,9 @@ calculate_heap_sizes()
     fi
 
     # set max heap size based on the following
-    # max(min(1/2 ram, 1024MB), min(1/4 ram, 8GB))
+    # max(min(1/2 ram, 1024MB), min(1/4 ram, 64GB))
     # calculate 1/2 ram and cap to 1024MB
     # calculate 1/4 ram and cap to 8192MB
     # pick the max
     half_system_memory_in_mb=`expr $system_memory_in_mb / 2`
     quarter_system_memory_in_mb=`expr $half_system_memory_in_mb / 2`
@@ -76,9 +76,9 @@ calculate_heap_sizes()
     then
         half_system_memory_in_mb="1024"
     fi
-    if [ "$quarter_system_memory_in_mb" -gt "8192" ]
+    if [ "$quarter_system_memory_in_mb" -gt "65536" ]
     then
-        quarter_system_memory_in_mb="8192"
+        quarter_system_memory_in_mb="65536"
     fi
     if [ "$half_system_memory_in_mb" -gt "$quarter_system_memory_in_mb" ]
     then
@@ -66,9 +66,9 @@ calculate_heap_sizes()
     # calculate 1/2 ram and cap to 1024MB
-    # calculate 1/4 ram and cap to 8192MB
+    # calculate 1/4 ram and cap to 65536MB
     # pick the max
     half_system_memory_in_mb=`expr $system_memory_in_mb / 2`